:mod:`art.defences.detector.evasion`
====================================
.. automodule:: art.defences.detector.evasion

Binary Input Detector
---------------------
.. autoclass:: BinaryInputDetector
   :members:

Binary Activation Detector
--------------------------
.. autoclass:: BinaryActivationDetector
   :members:
